==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/fe/ReportPane.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2020 Tridium, Inc. All Rights Reserved.
 */

/** @jsx spandrel.jsx */

/**
 * API Status: **Private**
 * @module nmodule/report/rc/fe/ReportPane
 */

define(['baja!', 'baja!gx:Brush,gx:Image', 'bajaux/spandrel', 'nmodule/bajaui/rc/ux/Picture', 'css!nmodule/report/rc/report'], function (baja, types, spandrel, Picture) {
  'use strict';

  var NULL_IMAGE = baja.$("gx:Image");
  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-ReportPane',
        logo: NULL_IMAGE,
        rowGap: 0,
        timestamp: true,
        pageNumber: true
      }
    };
  };
  function ReportPaneKids(kids, rowGap) {
    return kids.filter(function (kid) {
      return kid.getName() !== "scrollBar";
    }).map(function (kid, kidNum) {
      var kidStyle = {};
      var _kid$getProperties = kid.getProperties(),
        visible = _kid$getProperties.visible;
      if (!visible) {
        kidStyle.visibility = 'hidden';
      }
      if (kidNum > 0) {
        kidStyle.marginTop = "".concat(rowGap, "px");
      }
      return spandrel.jsx("div", {
        spandrelSrc: kid,
        style: kidStyle,
        className: "ux-use-preferred-height"
      });
    });
  }

  /**
   * @class
   * @alias nmodule/report/rc/fe/ReportPane
   * @extends module:bajaux/Widget
   */
  return /*#__PURE__*/function (_spandrel) {
    function ReportPane(params) {
      _classCallCheck(this, ReportPane);
      return _callSuper(this, ReportPane, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }
    _inherits(ReportPane, _spandrel);
    return _createClass(ReportPane);
  }(spandrel(function (model, _ref) {
    var properties = _ref.properties;
    var logo = properties.logo,
      rowGap = properties.rowGap;
    return spandrel.jsx("div", {
      spandrelKey: "wrapper",
      className: "reportPane-wrapper"
    }, spandrel.jsx(Picture, {
      spandrelKey: "logo",
      properties: {
        image: logo
      }
    }), spandrel.jsx("div", {
      spandrelKey: "reportPaneKids",
      className: "ReportPaneContent"
    }, ReportPaneKids(model.getKids(), rowGap)));
  }));
});

==> Tridium_EMEA_N4_Supervisor-4.14.2.12.zip: rc/fe/ReportPane.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2020 Tridium, Inc. All Rights Reserved.
 */

/** @jsx spandrel.jsx */

/**
 * API Status: **Private**
 * @module nmodule/report/rc/fe/ReportPane
 */

define(['baja!', 'baja!gx:Brush,gx:Image', 'bajaux/spandrel', 'nmodule/bajaui/rc/ux/Picture', 'css!nmodule/report/rc/report'], function (baja, types, spandrel, Picture) {
  'use strict';

  var NULL_IMAGE = baja.$("gx:Image");
  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-ReportPane',
        logo: NULL_IMAGE,
        rowGap: 0,
        timestamp: true,
        pageNumber: true
      }
    };
  };
  function ReportPaneKids(kids, rowGap) {
    return kids.filter(function (kid) {
      return kid.getName() !== "scrollBar";
    }).map(function (kid, kidNum) {
      var kidStyle = {};
      var _kid$getProperties = kid.getProperties(),
        visible = _kid$getProperties.visible;
      if (!visible) {
        kidStyle.visibility = 'hidden';
      }
      if (kidNum > 0) {
        kidStyle.marginTop = "".concat(rowGap, "px");
      }
      return spandrel.jsx("div", {
        spandrelSrc: kid,
        style: kidStyle,
        className: "ux-use-preferred-height"
      });
    });
  }

  /**
   * @class
   * @alias module:nmodule/report/rc/fe/ReportPane
   * @extends module:bajaux/Widget
   */
  return /*#__PURE__*/function (_spandrel) {
    function ReportPane(params) {
      _classCallCheck(this, ReportPane);
      return _callSuper(this, ReportPane, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }
    _inherits(ReportPane, _spandrel);
    return _createClass(ReportPane);
  }(spandrel(function (model, _ref) {
    var properties = _ref.properties;
    var logo = properties.logo,
      rowGap = properties.rowGap;
    return spandrel.jsx("div", {
      spandrelKey: "wrapper",
      className: "reportPane-wrapper"
    }, spandrel.jsx(Picture, {
      spandrelKey: "logo",
      properties: {
        image: logo
      }
    }), spandrel.jsx("div", {
      spandrelKey: "reportPaneKids",
      className: "ReportPaneContent"
    }, ReportPaneKids(model.getKids(), rowGap)));
  }));
});
